#!/usr/bin/perl

my ($section, %data);

while (<>)
{
    if (($key, $sizeSetting) = ($_ =~ /(Entry\d)=\.?([^\n]+)/) &&
        $key == "Size")
    {
        print "[General]\n";

        if ($sizeSetting == '24')
        {
            print "Size=0\n";
        }
        elsif ($sizeSetting == '30')
        {
            print "Size=1\n";
        }
        elsif ($sizeSetting == '46')
        {
            print "Size=2\n";
        }
        elsif ($sizeSetting == '58')
        {
            print "Size=3\n";
        }
        else
        {
            print "Size=4\n";
        }
    }
    exit(0);
}

