/****************************************************************************
** Form interface generated from reading ui file './HostConnector.ui'
**
** Created: Mon Apr 12 03:11:28 2004
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.2.1   edited May 19 14:22 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef HOSTCONNECTORE_H
#define HOSTCONNECTORE_H

#include <qvariant.h>
#include <qdialog.h>
#include <klocale.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QLabel;
class QComboBox;
class QPushButton;
class QButtonGroup;
class QRadioButton;
class QSpinBox;

class HostConnector : public QDialog
{
    Q_OBJECT

public:
    HostConnector( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~HostConnector();

    QLabel* hostLabel;
    QComboBox* host;
    QPushButton* helpButton;
    QPushButton* okButton;
    QPushButton* cancelButton;
    QButtonGroup* ButtonGroup6;
    QRadioButton* ssh;
    QRadioButton* rsh;
    QRadioButton* daemon;
    QRadioButton* custom;
    QComboBox* command;
    QLabel* TextLabel3;
    QLabel* TextLabel1;
    QLabel* TextLabel2_2;
    QSpinBox* port;
    QLabel* TextLabel2;

protected:
    QGridLayout* HostConnectoreLayout;
    QHBoxLayout* Layout17;
    QHBoxLayout* Layout4;
    QGridLayout* ButtonGroup6Layout;
    QHBoxLayout* Layout5;
    QVBoxLayout* Layout5_2;

protected slots:
    virtual void languageChange();

};

#endif // HOSTCONNECTORE_H
