/****************************************************************************
** Form interface generated from reading ui file './TimerSettings.ui'
**
** Created: Mon Apr 12 03:11:29 2004
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.2.1   edited May 19 14:22 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef TIMERSETTINGS_H
#define TIMERSETTINGS_H

#include <qvariant.h>
#include <qdialog.h>
#include <locale.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QGroupBox;
class QCheckBox;
class QLabel;
class QSpinBox;
class QPushButton;

class TimerSettings : public QDialog
{
    Q_OBJECT

public:
    TimerSettings( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~TimerSettings();

    QGroupBox* Properties;
    QCheckBox* useGlobalUpdate;
    QLabel* TextLabel1;
    QSpinBox* interval;
    QPushButton* okButton;
    QPushButton* cancelButton;

protected:
    QGridLayout* TimerSettingsLayout;
    QGridLayout* PropertiesLayout;

protected slots:
    virtual void languageChange();

};

#endif // TIMERSETTINGS_H
