<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="keditbookmarks" version="12">

<MenuBar>

<Menu name="file" noMerge="1"><text>&amp;File</text>
 <Action name="file_open"/>
 <Action name="file_save"/>
 <Action name="file_save_as"/>
 <Menu name="import" noMerge="1"><text>&amp;Import</text>
   <Action name="importIE"/>
   <Action name="importOpera"/>
   <Action name="importGaleon"/>
   <Action name="importKDE"/>
   <Action name="importMoz"/>
   <Action name="importNS"/>
 </Menu>
 <Menu name="export" noMerge="1"><text>&amp;Export</text>
   <Action name="exportMoz"/>
   <Action name="exportNS"/>
 </Menu>
 <Separator/>
 <Action name="file_quit"/>
</Menu>

<Menu name="edit"><text>&amp;Edit</text>
 <!-- The undo/redo/cut/copy/paste stuff goes here (ui_standards.rc) -->
 <Action name="rename"/>
 <Action name="changeurl"/>
 <!-- Action name="updatefavicon" -->
 <Action name="changeicon"/>
 <Action name="delete"/>
 <Separator/><!-- Stuff for folders -->
 <Action name="sort"/>
 <Action name="setastoolbar"/>
 <Separator/><!-- Expand/collapse -->
 <Action name="expandall"/>
 <Action name="collapseall"/>
</Menu>

<Menu name="insert"><text>&amp;Insert</text>
 <Action name="newbookmark"/>
 <Action name="newfolder"/>
 <Action name="insertseparator"/>
</Menu>

<Menu name="bookmark"><text>&amp;Bookmark</text>
 <Action name="openlink"/>
 <Action name="testlink"/>
 <Separator/>
 <Action name="testall"/>
 <Action name="canceltests"/>
</Menu>

<Menu name="settings"><text>&amp;Settings</text>
 <Action name="settings_showNS" append="save_merge"/>
</Menu>

</MenuBar>

<ToolBar name="mainToolBar" noMerge="1" fullWidth="true"><text>Main Toolbar</text>
 <Action name="file_save"/>
 <Action name="edit_undo"/>
 <Action name="edit_redo"/>
 <Action name="delete"/>
 <Action name="newbookmark"/>
 <Action name="newfolder"/>
</ToolBar>

<Menu name="popup_folder">
 <Action name="testlink"/>
             <!-- Edition -->
 <Action name="edit_undo"/>
 <Action name="edit_redo"/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <Separator/>
 <Action name="rename"/>
 <Action name="changeurl"/>
 <!-- Action name="updatefavicon" -->
 <Action name="changeicon"/>
 <Action name="delete"/>
 <Separator/><!-- Creation -->
 <Action name="newbookmark"/>
 <Action name="newfolder"/>
 <Action name="insertseparator"/>
 <Separator/><!-- Stuff for folders -->
 <Action name="sort"/>
 <Action name="setastoolbar"/>
</Menu>

<Menu name="popup_bookmark">
 <!-- Stuff for bookmarks -->
 <Action name="openlink"/>
 <Action name="testlink"/>
 <Separator/><!-- Edition -->
 <Action name="edit_undo"/>
 <Action name="edit_redo"/>
 <Action name="edit_cut"/>
 <Action name="edit_copy"/>
 <Action name="edit_paste"/>
 <Separator/>
 <Action name="rename"/>
 <Action name="changeurl"/>
 <!-- Action name="updatefavicon" -->
 <Action name="changeicon"/>
 <Separator/><!-- Creation -->
 <Action name="newbookmark"/>
 <Action name="newfolder"/>
 <Action name="insertseparator"/>
 <Separator/><!-- Dangerous actions :/ -->
 <Action name="delete"/>
</Menu>

</kpartgui>
