/****************************************************************************
** Form interface generated from reading ui file './StyleSettings.ui'
**
** Created: Mon Apr 12 03:11:28 2004
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.2.1   edited May 19 14:22 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef MYDIALOG1_H
#define MYDIALOG1_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class ColorPicker;
class QTabWidget;
class QWidget;
class QSpinBox;
class QLabel;
class QListBox;
class QListBoxItem;
class QPushButton;

class StyleSettings : public QDialog
{
    Q_OBJECT

public:
    StyleSettings( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~StyleSettings();

    QTabWidget* tabWidget;
    QWidget* Widget2;
    ColorPicker* backgroundColor;
    QSpinBox* fontSize;
    ColorPicker* fgColor1;
    ColorPicker* fgColor2;
    ColorPicker* alarmColor;
    QLabel* TextLabel1;
    QWidget* Widget3;
    QListBox* colorList;
    QPushButton* changeColor;
    QPushButton* buttonHelp;
    QPushButton* buttonApply;
    QPushButton* buttonOk;
    QPushButton* buttonCancel;

protected:
    QGridLayout* MyDialog1Layout;
    QGridLayout* Widget2Layout;
    QGridLayout* Widget3Layout;
    QHBoxLayout* Layout1;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;

};

#endif // MYDIALOG1_H
